#region  Copyright (c) 2004 Logitech, Inc. All Rights Reserved 
/////////////////////////////////////////////////////////////////////////////////
//                                                                             //
// Copyright (c) 2004 Logitech, Inc. All Rights Reserved                       //
//                                                                             //
// This program is a trade secret of LOGITECH, and it is not to be reproduced, //
// published, disclosed to others, copied, adapted, distributed or displayed   //
// without the prior written authorization of LOGITECH.                        //
//                                                                             //
// Licensee agrees to attach or embed this notice on all copies of the program //
// including partial copies or modified versions thereof.                      //
//                                                                             //
/////////////////////////////////////////////////////////////////////////////////
#endregion

using System;
using System.Diagnostics;
using System.Windows.Forms;

using Logitech.PlugIns;

namespace Logitech.PlugInTemplate
{
	public class ConfigurerController : IConfigurer
	{
		#region Initialization
		bool m_changed;
		UserControl m_view;

		public ConfigurerController()
		{
			m_changed = false;
		}

		public static ConfigurerController Create()
		{
			ConfigurerController controller = new ConfigurerController();
			ConfigurerView view = new ConfigurerView(controller);
			controller.View = view;
			return controller;
		}
		#endregion

		#region IConfigurer Implementation
		public UserControl View 
		{
			set { m_view = value; }
			get { return m_view; }
		}


		string m_configurationRoot;
		public string ConfigurationRoot
		{
			set 
			{ 
				Debug.Assert(value != string.Empty);
				m_configurationRoot = value; 
			}

			get 
			{ 
				Debug.Assert(m_configurationRoot != string.Empty);
				return m_configurationRoot; 
			}
		}


		public void ApplyChanges(bool forceSave)
		{
			if (m_changed || forceSave)
			{
				m_changed = false;
				SaveToRegistry();
			}
		}

		public event EventHandler SettingsChanged;
		#endregion

		#region Helpers
		internal void Changed()
		{
			m_changed = true;
			IConfigurerView view = (View as IConfigurerView);

			if(SettingsChanged != null)
			{
				//this should be try-catched and it should log in case of error
				SettingsChanged(this, null);
			}
		}

		internal void LoadFromRegistry()
		{		
			ConfigurerModel model = new ConfigurerModel();

			RegistrySerializer registrySerializer = new RegistrySerializer(ConfigurationRoot);
			//changed
			model.Tutor = registrySerializer.Tutor;
			//model.Group = registrySerializer.Group;
			

			(View as IConfigurerView).ConfigurerModel = model;
		}

		void SaveToRegistry()
		{
			ConfigurerModel model = (View as IConfigurerView).ConfigurerModel;

			RegistrySerializer registrySerializer = new RegistrySerializer(ConfigurationRoot);
			//changed
			registrySerializer.Tutor = model.Tutor;
			//registrySerializer.Group = model.Group;

			m_changed = false;
		}
		#endregion
	}
}
