#region  Copyright (c) 2004 Logitech, Inc. All Rights Reserved 
/////////////////////////////////////////////////////////////////////////////////
//                                                                             //
// Copyright (c) 2004 Logitech, Inc. All Rights Reserved                       //
//                                                                             //
// This program is a trade secret of LOGITECH, and it is not to be reproduced, //
// published, disclosed to others, copied, adapted, distributed or displayed   //
// without the prior written authorization of LOGITECH.                        //
//                                                                             //
// Licensee agrees to attach or embed this notice on all copies of the program //
// including partial copies or modified versions thereof.                      //
//                                                                             //
/////////////////////////////////////////////////////////////////////////////////
#endregion

using System;
using System.IO;
using System.Drawing;
using System.Drawing.Imaging;
using System.Diagnostics;

using Logitech.PlugIns;

using Logitech.Pen.Ink.Sdk;

namespace Logitech.PlugInTemplate
{
	public class StoreInFolder
	{
		#region Constants / Members
		IPlatform m_platform;
		RegistrySerializer m_registrySerializer;
		#endregion

		#region Initialization
		protected StoreInFolder()
		{
		}

		public StoreInFolder(IPlatform platform)
		{
			Debug.Assert(platform != null, "platform");
			m_platform = platform;
		}
		#endregion

		/* StoreItemInFolder gets the document (ioTag body) and the ioTag headers and set the first header (Subject) as filename and the second (To) as folder name
		 * and create the right path to store the document in the given folder */
		public void StoreItemInFolder(ISelectedItem[] selectedItems, object[] parameters)
		{
			Debug.Assert(selectedItems != null, "selectedItems");

			int counter = 0;
			foreach(ISelectedItem selectedItem in selectedItems)
			{
				// Getting the iDoc
				IDocument document = (IDocument)selectedItem.Object;
				if(!document.IncludesStrokes) DocumentSerializer.Load(document);

				// Getting the iTag info
				IExportContext exportContext = parameters[counter] as IExportContext;
				ITagInfo tagInfo = exportContext.TagInfo;
				string givenFilename = tagInfo.Header.Fields.Length > 0 ? tagInfo.Header.Fields[0].Text :  string.Empty;
				string givenFolder = tagInfo.Header.Fields.Length > 1 ? tagInfo.Header.Fields[1].Text :  string.Empty;

				// Creating path and store the document
				// NB!: Folder must exist or it will fail without notice. Enhancement possibility: create folder if it does not exist
				string newfilepath = Environment.GetFolderPath(Environment.SpecialFolder.Personal)+@"\My io Documents\"+givenFolder;
				string newfilename = Path.Combine(newfilepath, givenFilename+@".pen");
				DocumentSerializer.Save(document, newfilename);

				counter++;
			}


			return;
		}
		
	}
}
